memote.suite.reporting.reports.basic_report module
==================================================

.. automodule:: memote.suite.reporting.reports.basic_report
    :members:
    :undoc-members:
    :show-inheritance:
